# Generic Catalog Reader (GCR)
by [Yao-Yuan Mao](https://yymao.github.io)

A common reader interface for accessing generic catalogs. 

This package is used by LSST DESC for the [DESCQA](https://github.com/LSSTDESC/descqa) validation framework. See [this repo](https://github.com/LSSTDESC/gcr-catalogs) for an actual example of using GCR.


## Installation

    pip install GCR
